package org.example.proyectofinalmacedonia;


import javax.crypto.Cipher;
import javax.crypto.SecretKey;
 
// KEY SPECIFICATIONS
import java.security.spec.KeySpec;
import java.security.spec.AlgorithmParameterSpec;
import javax.crypto.spec.PBEKeySpec;
import javax.crypto.SecretKeyFactory;
import javax.crypto.spec.PBEParameterSpec;

//EXCEPTIONS
import java.security.InvalidAlgorithmParameterException;
import java.security.NoSuchAlgorithmException;
import java.security.InvalidKeyException;
import java.security.spec.InvalidKeySpecException;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.BadPaddingException;
import javax.crypto.IllegalBlockSizeException;

import android.util.Base64;

import java.io.UnsupportedEncodingException;
import java.io.IOException;
	 

public class EncriptarClase {
	
	public static String clave = "clave de encriptacion";
	Cipher ecipher;
	Cipher dcipher;
	 
	
	/**
	 * Constructor used to create this object. Responsible for setting and initializing 
	 * this object's encrypter and decrypter Chipher instances given a Secret Key and algorithm. 
	 * @param key Secret Key used to initialize both the encrypter and decrypter instances. 
	 * @param algorithm Which algorithm to use for creating the encrypter and decrypter instances. 
	 */
	EncriptarClase(SecretKey key, String algorithm) {
		try {
			ecipher = Cipher.getInstance(algorithm);
			dcipher = Cipher.getInstance(algorithm);
			ecipher.init(Cipher.ENCRYPT_MODE, key);
			dcipher.init(Cipher.DECRYPT_MODE, key);
		} catch (NoSuchPaddingException e) {
			System.out.println("EXCEPTION: NoSuchPaddingException");
		} catch (NoSuchAlgorithmException e) {
			System.out.println("EXCEPTION: NoSuchAlgorithmException");
		} catch (InvalidKeyException e) {
			System.out.println("EXCEPTION: InvalidKeyException");
		}
	}
	 
	
	
	/**
	 * Constructor used to create this object. Responsible for setting and initializing 
	 * this object's encrypter and decrypter Chipher instances given a Pass Phrase and algorithm. 
	 * @param passPhrase Pass Phrase used to initialize both the encrypter and decrypter instances.
	 */
	public EncriptarClase(String passPhrase) {

		// 8-bytes Salt
		byte[] salt = { (byte) 0xA9, (byte) 0x9B, (byte) 0xC8, (byte) 0x32,	(byte) 0x56, (byte) 0x34, (byte) 0xE3, (byte) 0x03 };

		int iterationCount = 19;

		try {

			KeySpec keySpec = new PBEKeySpec(passPhrase.toCharArray(), salt, iterationCount);
			SecretKey key = SecretKeyFactory.getInstance("PBEWithMD5AndDES").generateSecret(keySpec);

			ecipher = Cipher.getInstance(key.getAlgorithm());
			dcipher = Cipher.getInstance(key.getAlgorithm());

			//Preparamos los parmetros para el ecipther
			AlgorithmParameterSpec paramSpec = new PBEParameterSpec(salt, iterationCount);

			ecipher.init(Cipher.ENCRYPT_MODE, key, paramSpec);
			dcipher.init(Cipher.DECRYPT_MODE, key, paramSpec);

		} catch (InvalidAlgorithmParameterException e) {
			System.out.println("EXCEPTION: InvalidAlgorithmParameterException");
		} catch (InvalidKeySpecException e) {
			System.out.println("EXCEPTION: InvalidKeySpecException");
		} catch (NoSuchPaddingException e) {
			System.out.println("EXCEPTION: NoSuchPaddingException");
		} catch (NoSuchAlgorithmException e) {
			System.out.println("EXCEPTION: NoSuchAlgorithmException");
		} catch (InvalidKeyException e) {
			System.out.println("EXCEPTION: InvalidKeyException");
		}
	}
	
	

	/**
	 * Takes a single String as an argument and returns an Encrypted version of that String. 
	 * @param str String to be encrypted 
	 * @return <code>String</code> 
	 * Encrypted version of the provided String
	 */
	public String encrypt(String str) {
		try {
			// Encode the string into bytes using utf-8
			byte[] utf8 = str.getBytes("UTF8");

			// Encrypt
			byte[] enc = ecipher.doFinal(utf8);

			// Encode bytes to base64 to get a string
			return Base64.encodeToString(enc, Base64.DEFAULT);

		} catch (BadPaddingException e) {
		} catch (IllegalBlockSizeException e) {
		} catch (UnsupportedEncodingException e) {
		} catch (IOException e) {
		}
		return null;
	}

	
	
	/**
	 * Takes a encrypted String as an argument, decrypts and returns the decrypted String. 
	 * @param str Encrypted String to be decrypted
	 * @return <code>String</code> 
	 * Decrypted version of the provided String 
	 */
	public String decrypt(String str) {

		try {
			// Decode base64 to get bytes
			byte[] dec = Base64.decode(str, Base64.DEFAULT);

			// Decrypt
			byte[] utf8 = dcipher.doFinal(dec);

			// Decode using utf-8
			return new String(utf8, "UTF8");

		} catch (BadPaddingException e) {
		} catch (IllegalBlockSizeException e) {
		} catch (UnsupportedEncodingException e) {
		} catch (IOException e) {
		}
		
		return null;
	}


}