package org.example.proyectofinalmacedonia;


import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.media.MediaPlayer;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;


public class ProyectoFinalMacedonia extends FragmentActivity {
	
	
	private MediaPlayer mp;
	private boolean reproducirMusicaInicial  = true;

	
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.proyecto_final_macedonia);
		
		gestionarLlamadaRecibida();
		
		TextView texto = (TextView) findViewById(R.id.textView001);
		Animation animacion = AnimationUtils.loadAnimation(this,R.anim.giro_con_zoom);
		texto.startAnimation(animacion);
		
		
		Button bDibujar = (Button) findViewById(R.id.b_dibujar);
		animacion = AnimationUtils.loadAnimation(this,R.anim.desplazamiento_derecha);
		bDibujar.startAnimation(animacion);
		
		Button bEncriptar = (Button) findViewById(R.id.b_encriptar);
		animacion = AnimationUtils.loadAnimation(this,R.anim.desplazamiento_izquierda_aparecer);
		bEncriptar.startAnimation(animacion);
		
		Button bConversor = (Button) findViewById(R.id.b_conversor_divisas);
		animacion = AnimationUtils.loadAnimation(this,R.anim.desplazamiento_abajo_giro);
		bConversor.startAnimation(animacion);
		
		bDibujar.setOnClickListener(new OnClickListener() {
			public void onClick(View view) {
				lanzarDibujar(view);
			}
		});
		
		bEncriptar.setOnClickListener(new OnClickListener() {
			public void onClick(View view) {
				lanzarEncriptar(view);
			}
		});
		
		bConversor.setOnClickListener(new OnClickListener() {
			public void onClick(View view) {
				lanzarConversorDivisas(view);
			}
		});

		
		gestionarMusica();
		mp = MediaPlayer.create(this, R.raw.audio);
	}
	
	
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}
	
	
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {

		switch (item.getItemId()) {
		
		case R.id.acercaDe:
			lanzarAcercaDe(null);
			break;
		
		case R.id.config:
			lanzarConfiguracion(null);
			break;
		}

		return true;
	}
	
	
	
	public void lanzarDibujar(View view) {
		Intent i = new Intent(this, Dibujar.class);
		startActivity(i);
	}
	
	
	
	
	public void lanzarEncriptar(View view) {
		Intent i = new Intent(this, MetodoEncriptacion.class);
		startActivity(i);
	}
	
	
	
	public void lanzarConversorDivisas(View view) {
		Intent i = new Intent(this, ConversorDivisasMultiples.class);
		startActivity(i);
	}
	
	
	
	public void lanzarConfiguracion(View view) {
		Intent i = new Intent(this, Preferencias.class);
		startActivity(i);
	}
	
	
	
	public void lanzarAcercaDe(View view) {
		Intent i = new Intent(this, AcercaDe.class);
		startActivity(i);
	}
	
	
	
	@Override
	protected void onResume() {
		super.onResume();
		
		gestionarMusica();
		
		if (reproducirMusicaInicial) {
			mp.start();
		}
	}
	
	

	@Override
	protected void onPause() {
		if (reproducirMusicaInicial) {
			mp.pause();
		}
		
		super.onPause();
	}
	
	
	
	@Override
	protected void onSaveInstanceState(Bundle estadoEstado) {
		super.onSaveInstanceState(estadoEstado);
		
		if (reproducirMusicaInicial) {
			if (mp != null) {
				int pos = mp.getCurrentPosition();
				estadoEstado.putInt("posicion", pos);
			}
		}
	}

	
	
	@Override
	protected void onRestoreInstanceState(Bundle estadoEstado) {
		super.onRestoreInstanceState(estadoEstado);
		
		if (reproducirMusicaInicial) {
			if (estadoEstado != null && mp != null) {
				int pos = estadoEstado.getInt("posicion");
				mp.seekTo(pos);
			}
		}
	}
	
	
	
	public void gestionarMusica() {
		SharedPreferences pref = this.getSharedPreferences("org.example.proyectofinalmacedonia_preferences", Context.MODE_PRIVATE);
		
		reproducirMusicaInicial  = pref.getBoolean("musica_inicial", true);
	}
	
	
	
	public void gestionarLlamadaRecibida() {
	  	Bundle extras = getIntent().getExtras();
    	String mensaje = "";
    	boolean hayMensaje = false;
		
		if (extras != null) {
			if (extras.getString("INFORMACION_LLAMADA") != null) {
				mensaje  = extras.getString("INFORMACION_LLAMADA");
				
				getIntent().getExtras().remove("INFORMACION_LLAMADA");
				stopService(new Intent(this, ServicioLlamada.class));
				hayMensaje = true;
			}
		} 
		
		
		if (hayMensaje) {
			EncriptarClase encriptar = new EncriptarClase(EncriptarClase.clave);
			String encriptado = encriptar.encrypt(mensaje);
			
			MensajeDataSource msgDataSource = new MensajeDataSource(this);
			msgDataSource.open();
			msgDataSource.createMensaje(encriptado, this);
			msgDataSource.close();
		}
	}
	
	
}
